from colorama import Fore, Back, Style

class Square:
    def __init__(self, weight, height):
        self.weight = weight
        self.height = height
    
    def draw(self, size : int=1):
        for y in range(self.height*size):
            for x in range(self.weight*size):
                print("██", end='')
            print()


# -*- coding: utf-8 -*-
from setuptools import setup

modules = \
['eazy_square']
setup_kwargs = {
    'name': 'eazy-square',
    'version': '0.1.0',
    'description': 'Square(w, h).draw(size)',
    'long_description': None,
    'author': 'fab4key',
    'author_email': None,
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'py_modules': modules,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)
